Class FileMetadata
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<FileMetadata.Builder,FileMetadata>
A file to be added, updated, or deleted as part of a commit.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal StringThe full path to the file to be added or updated, including the name of the file.final StringblobId()The blob ID that contains the file information.static FileMetadata.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final FileModeTypeEnumfileMode()The extrapolated file mode permissions for the file.final StringThe extrapolated file mode permissions for the file.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends FileMetadata.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
absolutePath
The full path to the file to be added or updated, including the name of the file.
- Returns:
- The full path to the file to be added or updated, including the name of the file.
-
blobId
The blob ID that contains the file information.
- Returns:
- The blob ID that contains the file information.
-
fileMode
The extrapolated file mode permissions for the file. Valid values include EXECUTABLE and NORMAL.
If the service returns an enum value that is not available in the current SDK version,
fileModewill returnFileModeTypeEnum.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromfileModeAsString().- Returns:
- The extrapolated file mode permissions for the file. Valid values include EXECUTABLE and NORMAL.
- See Also:
-
fileModeAsString
The extrapolated file mode permissions for the file. Valid values include EXECUTABLE and NORMAL.
If the service returns an enum value that is not available in the current SDK version,
fileModewill returnFileModeTypeEnum.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromfileModeAsString().- Returns:
- The extrapolated file mode permissions for the file. Valid values include EXECUTABLE and NORMAL.
- See Also:
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<FileMetadata.Builder,FileMetadata>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-