Class PostCommentReplyRequest
java.lang.Object
software.amazon.awssdk.core.SdkRequest
software.amazon.awssdk.awscore.AwsRequest
software.amazon.awssdk.services.codecommit.model.CodeCommitRequest
software.amazon.awssdk.services.codecommit.model.PostCommentReplyRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<PostCommentReplyRequest.Builder,PostCommentReplyRequest>
@Generated("software.amazon.awssdk:codegen")
public final class PostCommentReplyRequest
extends CodeCommitRequest
implements ToCopyableBuilder<PostCommentReplyRequest.Builder,PostCommentReplyRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final StringA unique, client-generated idempotency token that, when provided in a request, ensures the request cannot be repeated with a changed parameter.final Stringcontent()The contents of your reply to a comment.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringThe system-generated ID of the comment to which you want to reply.static Class<? extends PostCommentReplyRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
inReplyTo
The system-generated ID of the comment to which you want to reply. To get this ID, use GetCommentsForComparedCommit or GetCommentsForPullRequest.
- Returns:
- The system-generated ID of the comment to which you want to reply. To get this ID, use GetCommentsForComparedCommit or GetCommentsForPullRequest.
-
clientRequestToken
A unique, client-generated idempotency token that, when provided in a request, ensures the request cannot be repeated with a changed parameter. If a request is received with the same parameters and a token is included, the request returns information about the initial request that used that token.
- Returns:
- A unique, client-generated idempotency token that, when provided in a request, ensures the request cannot be repeated with a changed parameter. If a request is received with the same parameters and a token is included, the request returns information about the initial request that used that token.
-
content
The contents of your reply to a comment.
- Returns:
- The contents of your reply to a comment.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<PostCommentReplyRequest.Builder,PostCommentReplyRequest> - Specified by:
toBuilderin classCodeCommitRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-