Class PullRequestSourceReferenceUpdatedEventMetadata
java.lang.Object
software.amazon.awssdk.services.codecommit.model.PullRequestSourceReferenceUpdatedEventMetadata
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<PullRequestSourceReferenceUpdatedEventMetadata.Builder,PullRequestSourceReferenceUpdatedEventMetadata>
@Generated("software.amazon.awssdk:codegen")
public final class PullRequestSourceReferenceUpdatedEventMetadata
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<PullRequestSourceReferenceUpdatedEventMetadata.Builder,PullRequestSourceReferenceUpdatedEventMetadata>
Information about an update to the source branch of a pull request.
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic interface -
Method Summary
Modifier and TypeMethodDescriptionfinal StringThe full commit ID of the commit in the source branch that was the tip of the branch at the time the pull request was updated.final StringThe full commit ID of the commit in the destination branch that was the tip of the branch at the time the pull request was updated.builder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringThe commit ID of the most recent commit that the source branch and the destination branch have in common.final StringThe name of the repository where the pull request was updated.static Class<? extends PullRequestSourceReferenceUpdatedEventMetadata.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
repositoryName
The name of the repository where the pull request was updated.
- Returns:
- The name of the repository where the pull request was updated.
-
beforeCommitId
The full commit ID of the commit in the destination branch that was the tip of the branch at the time the pull request was updated.
- Returns:
- The full commit ID of the commit in the destination branch that was the tip of the branch at the time the pull request was updated.
-
afterCommitId
The full commit ID of the commit in the source branch that was the tip of the branch at the time the pull request was updated.
- Returns:
- The full commit ID of the commit in the source branch that was the tip of the branch at the time the pull request was updated.
-
mergeBase
The commit ID of the most recent commit that the source branch and the destination branch have in common.
- Returns:
- The commit ID of the most recent commit that the source branch and the destination branch have in common.
-
toBuilder
-
builder
-
serializableBuilderClass
public static Class<? extends PullRequestSourceReferenceUpdatedEventMetadata.Builder> serializableBuilderClass() -
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-