Class RepositoryMetadata
java.lang.Object
software.amazon.awssdk.services.codecommit.model.RepositoryMetadata
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<RepositoryMetadata.Builder,RepositoryMetadata>
@Generated("software.amazon.awssdk:codegen")
public final class RepositoryMetadata
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<RepositoryMetadata.Builder,RepositoryMetadata>
Information about a repository.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal StringThe ID of the Amazon Web Services account associated with the repository.final Stringarn()The Amazon Resource Name (ARN) of the repository.static RepositoryMetadata.Builderbuilder()final StringThe URL to use for cloning the repository over HTTPS.final StringThe URL to use for cloning the repository over SSH.final InstantThe date and time the repository was created, in timestamp format.final StringThe repository's default branch name.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringkmsKeyId()The ID of the Key Management Service encryption key used to encrypt and decrypt the repository.final InstantThe date and time the repository was last modified, in timestamp format.final StringA comment or description about the repository.final StringThe ID of the repository.final StringThe repository's name.static Class<? extends RepositoryMetadata.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
accountId
The ID of the Amazon Web Services account associated with the repository.
- Returns:
- The ID of the Amazon Web Services account associated with the repository.
-
repositoryId
The ID of the repository.
- Returns:
- The ID of the repository.
-
repositoryName
The repository's name.
- Returns:
- The repository's name.
-
repositoryDescription
A comment or description about the repository.
- Returns:
- A comment or description about the repository.
-
defaultBranch
The repository's default branch name.
- Returns:
- The repository's default branch name.
-
lastModifiedDate
The date and time the repository was last modified, in timestamp format.
- Returns:
- The date and time the repository was last modified, in timestamp format.
-
creationDate
The date and time the repository was created, in timestamp format.
- Returns:
- The date and time the repository was created, in timestamp format.
-
cloneUrlHttp
The URL to use for cloning the repository over HTTPS.
- Returns:
- The URL to use for cloning the repository over HTTPS.
-
cloneUrlSsh
The URL to use for cloning the repository over SSH.
- Returns:
- The URL to use for cloning the repository over SSH.
-
arn
The Amazon Resource Name (ARN) of the repository.
- Returns:
- The Amazon Resource Name (ARN) of the repository.
-
kmsKeyId
The ID of the Key Management Service encryption key used to encrypt and decrypt the repository.
- Returns:
- The ID of the Key Management Service encryption key used to encrypt and decrypt the repository.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<RepositoryMetadata.Builder,RepositoryMetadata>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-