Class SetFileModeEntry
java.lang.Object
software.amazon.awssdk.services.codecommit.model.SetFileModeEntry
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<SetFileModeEntry.Builder,SetFileModeEntry>
@Generated("software.amazon.awssdk:codegen")
public final class SetFileModeEntry
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<SetFileModeEntry.Builder,SetFileModeEntry>
Information about the file mode changes.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic SetFileModeEntry.Builderbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final FileModeTypeEnumfileMode()The file mode for the file.final StringThe file mode for the file.final StringfilePath()The full path to the file, including the name of the file.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends SetFileModeEntry.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
filePath
The full path to the file, including the name of the file.
- Returns:
- The full path to the file, including the name of the file.
-
fileMode
The file mode for the file.
If the service returns an enum value that is not available in the current SDK version,
fileModewill returnFileModeTypeEnum.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromfileModeAsString().- Returns:
- The file mode for the file.
- See Also:
-
fileModeAsString
The file mode for the file.
If the service returns an enum value that is not available in the current SDK version,
fileModewill returnFileModeTypeEnum.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available fromfileModeAsString().- Returns:
- The file mode for the file.
- See Also:
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<SetFileModeEntry.Builder,SetFileModeEntry>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-