Class SubModule
java.lang.Object
software.amazon.awssdk.services.codecommit.model.SubModule
- All Implemented Interfaces:
Serializable,SdkPojo,ToCopyableBuilder<SubModule.Builder,SubModule>
@Generated("software.amazon.awssdk:codegen")
public final class SubModule
extends Object
implements SdkPojo, Serializable, ToCopyableBuilder<SubModule.Builder,SubModule>
Returns information about a submodule reference in a repository folder.
- See Also:
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal StringThe fully qualified path to the folder that contains the reference to the submodule.static SubModule.Builderbuilder()final StringcommitId()The commit ID that contains the reference to the submodule.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringThe relative path of the submodule from the folder where the query originated.static Class<? extends SubModule.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
commitId
The commit ID that contains the reference to the submodule.
- Returns:
- The commit ID that contains the reference to the submodule.
-
absolutePath
The fully qualified path to the folder that contains the reference to the submodule.
- Returns:
- The fully qualified path to the folder that contains the reference to the submodule.
-
relativePath
The relative path of the submodule from the folder where the query originated.
- Returns:
- The relative path of the submodule from the folder where the query originated.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<SubModule.Builder,SubModule>
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode() -
equals
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-