Class UpdateCommentRequest
java.lang.Object
software.amazon.awssdk.core.SdkRequest
software.amazon.awssdk.awscore.AwsRequest
software.amazon.awssdk.services.codecommit.model.CodeCommitRequest
software.amazon.awssdk.services.codecommit.model.UpdateCommentRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<UpdateCommentRequest.Builder,UpdateCommentRequest>
@Generated("software.amazon.awssdk:codegen")
public final class UpdateCommentRequest
extends CodeCommitRequest
implements ToCopyableBuilder<UpdateCommentRequest.Builder,UpdateCommentRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionstatic UpdateCommentRequest.Builderbuilder()final StringThe system-generated ID of the comment you want to update.final Stringcontent()The updated content to replace the existing content of the comment.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends UpdateCommentRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
commentId
The system-generated ID of the comment you want to update. To get this ID, use GetCommentsForComparedCommit or GetCommentsForPullRequest.
- Returns:
- The system-generated ID of the comment you want to update. To get this ID, use GetCommentsForComparedCommit or GetCommentsForPullRequest.
-
content
The updated content to replace the existing content of the comment.
- Returns:
- The updated content to replace the existing content of the comment.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<UpdateCommentRequest.Builder,UpdateCommentRequest> - Specified by:
toBuilderin classCodeCommitRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-