Uses of Class
software.amazon.awssdk.services.codecommit.model.RepositoryNotAssociatedWithPullRequestException
Packages that use RepositoryNotAssociatedWithPullRequestException
-
Uses of RepositoryNotAssociatedWithPullRequestException in software.amazon.awssdk.services.codecommit
Methods in software.amazon.awssdk.services.codecommit that throw RepositoryNotAssociatedWithPullRequestExceptionModifier and TypeMethodDescriptionCodeCommitClient.getCommentsForPullRequest(Consumer<GetCommentsForPullRequestRequest.Builder> getCommentsForPullRequestRequest) Returns comments made on a pull request.CodeCommitClient.getCommentsForPullRequest(GetCommentsForPullRequestRequest getCommentsForPullRequestRequest) Returns comments made on a pull request.CodeCommitClient.getCommentsForPullRequestPaginator(Consumer<GetCommentsForPullRequestRequest.Builder> getCommentsForPullRequestRequest) This is a variant ofCodeCommitClient.getCommentsForPullRequest(software.amazon.awssdk.services.codecommit.model.GetCommentsForPullRequestRequest)operation.CodeCommitClient.getCommentsForPullRequestPaginator(GetCommentsForPullRequestRequest getCommentsForPullRequestRequest) This is a variant ofCodeCommitClient.getCommentsForPullRequest(software.amazon.awssdk.services.codecommit.model.GetCommentsForPullRequestRequest)operation.CodeCommitClient.mergePullRequestByFastForward(Consumer<MergePullRequestByFastForwardRequest.Builder> mergePullRequestByFastForwardRequest) Attempts to merge the source commit of a pull request into the specified destination branch for that pull request at the specified commit using the fast-forward merge strategy.CodeCommitClient.mergePullRequestByFastForward(MergePullRequestByFastForwardRequest mergePullRequestByFastForwardRequest) Attempts to merge the source commit of a pull request into the specified destination branch for that pull request at the specified commit using the fast-forward merge strategy.default MergePullRequestBySquashResponseCodeCommitClient.mergePullRequestBySquash(Consumer<MergePullRequestBySquashRequest.Builder> mergePullRequestBySquashRequest) Attempts to merge the source commit of a pull request into the specified destination branch for that pull request at the specified commit using the squash merge strategy.default MergePullRequestBySquashResponseCodeCommitClient.mergePullRequestBySquash(MergePullRequestBySquashRequest mergePullRequestBySquashRequest) Attempts to merge the source commit of a pull request into the specified destination branch for that pull request at the specified commit using the squash merge strategy.CodeCommitClient.mergePullRequestByThreeWay(Consumer<MergePullRequestByThreeWayRequest.Builder> mergePullRequestByThreeWayRequest) Attempts to merge the source commit of a pull request into the specified destination branch for that pull request at the specified commit using the three-way merge strategy.CodeCommitClient.mergePullRequestByThreeWay(MergePullRequestByThreeWayRequest mergePullRequestByThreeWayRequest) Attempts to merge the source commit of a pull request into the specified destination branch for that pull request at the specified commit using the three-way merge strategy.CodeCommitClient.postCommentForPullRequest(Consumer<PostCommentForPullRequestRequest.Builder> postCommentForPullRequestRequest) Posts a comment on a pull request.CodeCommitClient.postCommentForPullRequest(PostCommentForPullRequestRequest postCommentForPullRequestRequest) Posts a comment on a pull request.